---
title: Llamaindex
sidebarTitle: Llamaindex
---

![Llamaindex Example](img/ecosystem-llamaindex.png)

[Llamaindex](https://www.llamaindex.ai/) allows the users to create Llamaindex agents and integrate them in AG2 conversation patterns.

- [Llamaindex + AG2 Code Examples](https://github.com/ag2ai/ag2/blob/main/notebook/agentchat_group_chat_with_llamaindex_agents.ipynb)
